====================
Multiple attach volume
====================


Use Case
--------
Since multiple volume attaching support to OpenStack Mitaka, one volume can be attached to several
instances or hosts, rally should add scenarios about multiple attach volume.


Problem Description
-------------------
Rally lack of scenarios about multiple attach volume


Possible solution
-----------------
* Add nova scenarios "multi_attach_volume" and "multi_detach_volume"
